@@ -429,7 +429,7 @@ class DeviceInterface:
 
         self.cortex_m.nodebug()
 
-        if is_locked:
+        if not is_locked:
             return True
         else:
-            return False
\ No newline at end of file
+            return False
